pub struct Context { /* private fields */ }Expand description
The device independent part of an Ethernet network interface.
Separating the device from the data required for processing and dispatching makes
it possible to borrow them independently. For example, the tx and rx tokens borrow
the device mutably until they’re used, which makes it impossible to call other
methods on the Interface in this time (since its device field is borrowed
exclusively). However, it is still possible to call methods on its inner field.
Implementations
Sourceimpl InterfaceInner
impl InterfaceInner
Sourcepub fn ipv4_addr(&self) -> Option<Ipv4Address>
pub fn ipv4_addr(&self) -> Option<Ipv4Address>
Get the first IPv4 address of the interface.