Struct DnsQuestion
Source pub struct DnsQuestion<'a> {
pub name: &'a [u8],
pub type_: Type,
}
Return the length of a packet that will be emitted from this high-level representation.
Emit a high-level representation into a DNS packet.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.